import pickle
import os
from utils import load_pickle
from file_formats_scrapper import load_common_extensions, load_extension_data
from constants import EXTENSIONS_PICKLE_FILE_NAME

extensions = {}

# updates the golbal extensions object with data in pickle file.
def load_extensions_object():
    global extensions
    extensions = load_pickle(EXTENSIONS_PICKLE_FILE_NAME)

# If there exist pickle file just use it. Else load common data from fileInfo.
if os.path.isfile(EXTENSIONS_PICKLE_FILE_NAME):
    load_extensions_object()
else:
    load_common_extensions()
    load_extensions_object()


def getExtensionCategory(extension):
    extension = extension.lower()
    category = list(filter(lambda cat: extension in cat[1], extensions.items())) # Some magical python to check if a category contains the extension
    if len(category) == 0:
        category = load_extension_data(extension) # not found in the local extension, What about checking it in fileInfo servers?
        load_extensions_object()
        return category
    else:
        return category[0][0]



import requests
import os
import pickle
from bs4 import BeautifulSoup
from constants import EXTENSIONS_PICKLE_FILE_NAME
from utils import save_pickle, load_pickle

# Used to initilally load the common extensions from file info.
# It contains many (but not all) extensions
def load_common_extensions():
    print(f"loading all common data from fileinfo..")
    source = requests.get("https://fileinfo.com/filetypes/common")
    soup = BeautifulSoup(source.content,'html.parser')

    file_categories = soup.find_all('table', class_="list common browselist")
    extensions = {}
    for category_data in file_categories:
        cateogry_name = category_data.select_one("th").get_text().lower()
        category_extensions = category_data.select("td a")
        for extension in category_extensions:
            extension = extension.get_text().lower()
            if cateogry_name in extensions.keys():
                extensions[cateogry_name].append(extension)
            else:
                extensions[cateogry_name] = [extension]
    save_pickle(EXTENSIONS_PICKLE_FILE_NAME, extensions)

# Loads specific extention data from fileInfo
def load_extension_data(extension):
    print(f"loading {extension} data from fileinfo..")
    source = requests.get(f"https://fileinfo.com/extension/{extension.split('.')[1]}")
    if(source.status_code != 200):
        return None
    soup = BeautifulSoup(source.content,'html.parser')
    current_pickle_data = load_pickle(EXTENSIONS_PICKLE_FILE_NAME)
    category = soup.select(".headerInfo tr:nth-child(3) a")[0].get_text().lower()
    if category in current_pickle_data.keys():
        current_pickle_data[category].append(extension)
    else:
        current_pickle_data[category] = [extension]
    save_pickle(EXTENSIONS_PICKLE_FILE_NAME, current_pickle_data)
    return category




import os
import sys
import shutil  # for moving and copyinf items
from pathlib import Path
from os import listdir
from os.path import isfile, join
from utils import get_file_extension
from file_extensions_handler import getExtensionCategory

def organise(filelist, directory):
    # moves files in folders accordind to their extentions
    for my_file in filelist:
        file_category = getExtensionCategory(get_file_extension(my_file))
        loc = directory+"\\"
        if file_category != None:
            loc += file_category
        else:
            loc += "Unknown Extensions" # not in the file formats
        Path(loc).mkdir(exist_ok=True)
        shutil.move(my_file, loc)
        print(f"moved {my_file} to {loc}")

def organise_directory(directory):
    files = [join(directory, f) for f in listdir(directory) if isfile(join(directory, f))]
    organise(files, directory)
    print(f"Organised {len(files)} files into their directories")
            
def main():
    directory_tobe_cleaned = ""
    if len(sys.argv) < 2:
        print(f"""Please enter a directory to clean. 
        as \"py {sys.argv[0]} path/to/directory\"""")
        exit()
    else:
        directory_tobe_cleaned = sys.argv[1]
    organise_directory(directory_tobe_cleaned)
    print("Done!")

main()


import os.path
import pickle

def get_file_extension(filePath):
    extension = os.path.splitext(filePath)[1]
    return extension

    
def load_pickle(file_name):
    pickle_file = open(file_name,"rb")
    pickle_data = pickle.load(pickle_file)
    pickle_file.close()
    return pickle_data

def save_pickle(file_name, data):
    pickle_file = open(file_name, "wb")
    pickle.dump(data,pickle_file)
    pickle_file.close()